"""Module containing constants in azol"""
from dataclasses import dataclass
from pathlib import Path

ARMURL="https://management.azure.com"
GRAPHBETAURL="https://graph.microsoft.com/beta"
GRAPHV1URL="https://graph.microsoft.com/v1.0"
KEYVAULTURL="https://vault.azure.net"
KEYVAULTAPIVERSION="7.3"
IDENTITYPLATFORMURL="https://login.microsoftonline.com"
DEFAULTSCOPE=".default"

homeDirectory = Path.home()
AZOL_HOME = str(homeDirectory) + "/.azol"
PROVIDER_CACHE_DIR = AZOL_HOME + "/provider_cache"
PROVIDER_CACHE = AZOL_HOME + "/provider_cache/refresh"
AZOLSECRETPROVIDERFOLDER = AZOL_HOME + "/secrets"
TOKENCACHEDIR = AZOL_HOME + "/token_cache"

@dataclass(frozen=True)
class OAuthResourceIDs:
    """
        A data class containing constant strings for OAuth flow types
    """
    Arm="https://management.azure.com/"
    Graph="https://graph.microsoft.com/"
    KeyVault="https://vault.azure.net/"
    CosmosDB="https://cosmos.azure.com/"
    AzureDataLake="https://datalake.azure.net/"
    AzureSQL="https://database.windows.net/"
    OneNote="https://onenote.com/"
    AzureDevOps="https://app.vssps.visualstudio.com/"
    StorageAccount="https://storage.azure.com/"
    Sharepoint="https://microsoft.sharepoint.com"
    PowerBI="https://analysis.windows.net/powerbi/api/"
    PowerAutomate="https://service.flow.microsoft.com/"
    DynamicsCRM="https://admin.services.crm.dynamics.com/"
    Intune="https://api.manage.microsoft.com/"
    OfficeManagement="https://manage.office.com/"
    DynamicsBusinessCentral="https://dynamics.microsoft.com/business-central/overview/"
    Yammer="https://api.yammer.com/"
    SkypeForBusiness="https://api.skypeforbusiness.com/"
    AzureCommunicationServices="https://auth.msft.communication.azure.com"


@dataclass(frozen=True)
class OAUTHFLOWS:
    """
        A data class containing constant strings for OAuth flow types
    """
    CLIENT_CREDENTIALS="client_credentials"
    DEVICE_CODE="device_code"
    REFRESH_TOKEN="refresh_token"
    RAW_TOKEN="raw_token"

@dataclass(frozen=True)
class FOCIClients:
    """
        A data class containing client IDs for FOCI Clients

        Taken from here: https://github.com/secureworks/family-of-client-ids-research/blob/main/known-foci-clients.csv
    """
    Office365Management="00b41c95-dab0-4487-9791-b9d2c32c80f2"
    MicrosoftAzurePowershell="1950a258-227b-4e31-a9cf-717495945fc2"
    MicrosoftAzureCLI="04b07795-8ddb-461a-bbee-02f9e1bf7b46"
    MicrosoftTeams="1fec8e78-bce4-4aaf-ab1b-5451cc387264"
    WindowsSearch="26a7ee05-5602-4d76-a7ba-eae8b7b67941"
    OutlookMobile="27922004-5251-4030-b22d-91ecd9a37ea4"
    MicrosoftAuthenticatorApp="4813382a-8fa7-425e-ab75-3b753aab3abb"
    OneDriveSyncEngine="ab9b8c07-8f02-4f72-87fa-80105867a763"
    MicrosoftOffice="d3590ed6-52b3-4102-aeff-aad2292ab01c"
    VisualStudio="872cd9fa-d31f-45e0-9eab-6e460a02d1f1"
    OneDriveiOSApp="af124e86-4e96-495a-b70a-90f90ab96707"
    MicrosoftBingSearchForMicrosoftEdge="2d7f3606-b07d-41d1-b9d2-0d0c9296a6e8"
    MicrosoftStreamMobileNative="844cca35-0656-46ce-b636-13f48b0eecbd"
    MicrosoftTeamsDeviceAdminAgent="87749df4-7ccf-48f8-aa87-704bad0e0e16"
    MicrosoftBingSearch="cf36b471-5b44-428c-9ce7-313bf84528de"
    OfficeUWPPWA="0ec893e0-5785-4de6-99da-4ed124e5296c"
    MicrosoftToDoClient="22098786-6e16-43cc-a27d-191a01a1e3b5"
    PowerApps="4e291c71-d680-4d0e-9640-0a3358e31177"
    MicrosoftWhiteboardClient="57336123-6e14-4acc-8dcf-287b6088aa28"
    MicrosoftFlow="57fcbcfa-7cee-4eb1-8b25-12d2030b4ee0"
    MicrosoftPlanner="66375f6b-983f-4c2c-9701-d680650f588f"
    MicrosoftIntuneCompanyPortal="9ba1a5c7-f17a-4de9-a1f1-6178c8d51223"
    AccountsControlUI="a40d7d7d-59aa-447e-a655-679a4107e548"
    YammeriPhone="a569458c-7f2b-45cb-bab9-b7dee514d112"
    OneDrive="b26aadf8-566f-4478-926f-589f601d9c74"
    MicrosoftPowerBI="c0d2a505-13b8-4ae0-aa9e-cddd5eab0b12"
    SharePoint="d326c1ce-6cc6-4de2-bebc-4591e5e13ef0"
    MicrosoftEdge="e9c51622-460d-4d3d-952d-966a5b1da34c"
    MicrosoftTunnel="eb539595-3fe1-474e-9c1d-feb3625d1be5"
    MicrosoftEdge2="ecd6b820-32c2-49b6-98a6-444530e5a77a"
    SharePointAndroid="f05ff7c9-f75a-4acd-a3b5-f4b6a870245d"
    MicrosoftEdge3="f44b1140-bc5e-48c6-8dc0-5cf5a53c0e34"
    M365ComplianceDriveClient="be1918be-3fe3-4be9-b32b-b542fc27f02e"
    MicrosoftDefenderPlatform="cab96880-db5b-4e15-90a7-f3f1d62ffe39"
    MicrosoftEdgeEnterpriseNewTabPage="d7b530a4-7680-4c23-a8bf-c52c121d2e87"
    MicrosoftDefenderForMobile="dd47d17a-3194-4d86-bfd5-c6ae6f5651e3"
    OutlookLite="e9b154d0-7658-433b-bb25-6b8e0a8a7c59"

@dataclass(frozen=True)
class GraphAPIPermissions:
    """
        All Entra RBAC Role names mapped to their ids in a frozen data class
    """

@dataclass(frozen=True)
class EntraRolesDefinitionIds:
    """
        All Entra RBAC Role names mapped to their ids in a frozen data class
    """

@dataclass(frozen=True)
class RBACRoleDefinitionIds:
    """
        All Azure RBAC Role names mapped to their ids in a frozen data class
    """
    AcrPush="8311e382-0749-4cb8-b61a-304f252e45ec"
    API_Management_Service_Contributor="312a565d-c81f-4fd8-895a-4e21e48d571c"
    AcrPull="7f951dda-4ed3-4680-a7ca-43fe172d538d"
    AcrImageSigner="6cef56e8-d556-48e5-a04f-b8e64114680f"
    AcrDelete="c2f4ef07-c644-48eb-af81-4b1b4947fb11"
    AcrQuarantineReader="cdda3590-29a3-44f6-95f2-9f980659eb04"
    AcrQuarantineWriter="c8d4ff99-41c3-41a8-9f60-21dfdad59608"
    API_Management_Service_Operator_Role="e022efe7-f5ba-4159-bbe4-b44f577e9b61"
    API_Management_Service_Reader_Role="71522526-b88f-4d52-b57f-d31fc3546d0d"
    Application_Insights_Component_Contributor="ae349356-3a1b-4a5e-921d-050484c6347e"
    Application_Insights_Snapshot_Debugger="08954f03-6346-4c2e-81c0-ec3a5cfae23b"
    Attestation_Reader="fd1bd22b-8476-40bc-a0bc-69b95687b9f3"
    Automation_Job_Operator="4fe576fe-1146-4730-92eb-48519fa6bf9f"
    Automation_Runbook_Operator="5fb5aef8-1081-4b8e-bb16-9d5d0385bab5"
    Automation_Operator="d3881f73-407a-4167-8283-e981cbba0404"
    Avere_Contributor="4f8fab4f-1852-4a58-a46a-8eaf358af14a"
    Avere_Operator="c025889f-8102-4ebf-b32c-fc0c6f0c6bd9"
    Azure_Kubernetes_Service_Cluster_Admin_Role="0ab0b1a8-8aac-4efd-b8c2-3ee1fb270be8"
    Azure_Kubernetes_Service_Cluster_User_Role="4abbcc35-e782-43d8-92c5-2d3f1bd2253f"
    Azure_Maps_Data_Reader="423170ca-a8f6-4b0f-8487-9e4eb8f49bfa"
    Azure_Stack_Registration_Owner="6f12a6df-dd06-4f3e-bcb1-ce8be600526a"
    Backup_Contributor="5e467623-bb1f-42f4-a55d-6e525e11384b"
    Billing_Reader="fa23ad8b-c56e-40d8-ac0c-ce449e1d2c64"
    Backup_Reader="a795c7a0-d4a2-40c1-ae25-d81f01202912"
    Blockchain_Member_Node_Access="31a002a1-acaf-453e-8a5b-297c9ca1ea24"
    BizTalk_Contributor="5e3c6656-6cfa-4708-81fe-0de47ac73342"
    CDN_Endpoint_Contributor="426e0c7f-0c7e-4658-b36f-ff54d6c29b45"
    CDN_Profile_Contributor="ec156ff8-a8d1-4d15-830c-5b80698ca432"
    CDN_Profile_Reader="8f96442b-4075-438f-813d-ad51ab4019af"
    Classic_Network_Contributor="b34d265f-36f7-4a0d-a4d4-e158ca92e90f"
    Classic_Storage_Account_Contributor="86e8f5dc-a6e9-4c67-9d15-de283e8eac25"
    Classic_Storage_Account_Key_Operator_Service_Role="985d6b00-f706-48f5-a6fe-d0ca12fb668d"
    ClearDB_MySQL_DB_Contributor="9106cda0-8a86-4e81-b686-29a22c54effe"
    Classic_Virtual_Machine_Contributor="d73bb868-a0df-4d4d-bd69-98a00b01fccb"
    Cognitive_Services_User="a97b65f3-24c7-4388-baec-2e87135dc908"
    Cognitive_Services_Data_Reader="b59867f0-fa02-499b-be73-45a86b5b3e1c"
    Cognitive_Services_Contributor="25fbc0a9-bd7c-42a3-aa1a-3b75d497ee68"
    CosmosBackupOperator="db7b14f2-5adf-42da-9f96-f2ee17bab5cb"
    Contributor="b24988ac-6180-42a0-ab88-20f7382dd24c"
    Cosmos_DB_Account_Reader_Role="fbdf93bf-df7d-467e-a4d2-9458aa1360c8"
    Cost_Management_Contributor="434105ed-43f6-45c7-a02f-909b2ba83430"
    Cost_Management_Reader="72fafb9e-0641-4937-9268-a91bfd8191a3"
    Data_Box_Contributor="add466c9-e687-43fc-8d98-dfcf8d720be5"
    Data_Box_Reader="028f4ed7-e2a9-465e-a8f4-9c0ffdfdc027"
    Data_Factory_Contributor="673868aa-7521-48a0-acc6-0f60742d39f5"
    Data_Purger="150f5e0c-0603-4f03-8c7f-cf70034c4e90"
    Data_Lake_Analytics_Developer="47b7735b-770e-4598-a7da-8b91488b4c88"
    DevTest_Labs_User="76283e04-6283-4c54-8f91-bcf1374a3c64"
    DocumentDB_Account_Contributor="5bd9cd88-fe45-4216-938b-f97437e15450"
    DNS_Zone_Contributor="befefa01-2a29-4197-83a8-272ff33ce314"
    EventGrid_EventSubscription_Contributor="428e0ff0-5e57-4d9c-a221-2c70d0e0a443"
    EventGrid_EventSubscription_Reader="2414bbcf-6497-4faf-8c65-045460748405"
    Graph_Owner="b60367af-1334-4454-b71e-769d9a4f83d9"
    HDInsight_Domain_Services_Contributor="8d8d5a11-05d3-4bda-a417-a08778121c7c"
    Intelligent_Systems_Account_Contributor="03a6d094-3444-4b3d-88af-7477090a9e5e"
    Key_Vault_Contributor="f25e0fa2-a7c8-4377-a976-54943a77a395"
    Knowledge_Consumer="ee361c5d-f7b5-4119-b4b6-892157c8f64c"
    Lab_Creator="b97fb8bc-a8b2-4522-a38b-dd33c7e65ead"
    Log_Analytics_Reader="73c42c96-874c-492b-b04d-ab87d138a893"
    Log_Analytics_Contributor="92aaf0da-9dab-42b6-94a3-d43ce8d16293"
    Logic_App_Operator="515c2055-d9d4-4321-b1b9-bd0c9a0f79fe"
    Logic_App_Contributor="87a39d53-fc1b-424a-814c-f7e04687dc9e"
    Managed_Application_Operator_Role="c7393b34-138c-406f-901b-d8cf2b17e6ae"
    Managed_Applications_Reader="b9331d33-8a36-4f8c-b097-4f54124fdb44"
    Managed_Identity_Operator="f1a07417-d97a-45cb-824c-7a7467783830"
    Managed_Identity_Contributor="e40ec5ca-96e0-45a2-b4ff-59039f2c2b59"
    Management_Group_Contributor="5d58bcaf-24a5-4b20-bdb6-eed9f69fbe4c"
    Management_Group_Reader="ac63b705-f282-497d-ac71-919bf39d939d"
    Monitoring_Reader="43d0d8ad-25c7-4714-9337-8ba259a9fe05"
    Network_Contributor="4d97b98b-1d4f-4787-a291-c67834d212e7"
    New_Relic_APM_Account_Contributor="5d28c62d-5b37-4476-8438-e587778df237"
    Owner="8e3af657-a8ff-443c-a75c-2fe8c4bcb635"
    Reader="acdd72a7-3385-48ef-bd42-f606fba81ae7"
    Redis_Cache_Contributor="e0f68234-74aa-48ed-b826-c38b57376e17"
    Reader_and_Data_Access="c12c1c16-33a1-487b-954d-41c89c60f349"
    Resource_Policy_Contributor="36243c78-bf99-498c-9df9-86d9f8d28608"
    Scheduler_Job_Collections_Contributor="188a0f2f-5c9e-469b-ae67-2aa5ce574b94"
    Search_Service_Contributor="7ca78c08-252a-4471-8644-bb5ff32d4ba0"
    Security_Manager="e3d13bf0-dd5a-482e-ba6b-9b8433878d10"
    Security_Reader="39bc4728-0917-49c7-9d2c-d95423bc2eb4"
    Spatial_Anchors_Account_Contributor="8bbe83f1-e2a6-4df7-8cb4-4e04d4e5c827"
    Site_Recovery_Contributor="6670b86e-a3f7-4917-ac9b-5d6ab1be4567"
    Site_Recovery_Operator="494ae006-db33-4328-bf46-533a6560a3ca"
    Spatial_Anchors_Account_Reader="5d51204f-eb77-4b1c-b86a-2ec626c49413"
    Site_Recovery_Reader="dbaa88c4-0c30-4179-9fb3-46319faa6149"
    Spatial_Anchors_Account_Owner="70bbe301-9835-447d-afdd-19eb3167307c"
    SQL_Managed_Instance_Contributor="4939a1f6-9ae0-4e48-a1e0-f2cbe897382d"
    SQL_DB_Contributor="9b7fa17d-e63e-47b0-bb0a-15c516ac86ec"
    SQL_Security_Manager="056cd41c-7e88-42e1-933e-88ba6a50c9c3"
    Storage_Account_Contributor="17d1049b-9a84-46fb-8f53-869881c3d3ab"
    SQL_Server_Contributor="6d8ee4ec-f05a-4a1d-8b00-a9b17e38b437"
    Storage_Account_Key_Operator_Service_Role="81a9662b-bebf-436f-a333-f67b29880f12"
    Storage_Blob_Data_Contributor="ba92f5b4-2d11-453d-a403-e96b0029c9fe"
    Storage_Blob_Data_Owner="b7e6dc6d-f1e8-4753-8033-0f276bb0955b"
    Storage_Blob_Data_Reader="2a2b9908-6ea1-4ae2-8e65-a410df84e7d1"
    Storage_Queue_Data_Contributor="974c5e8b-45b9-4653-ba55-5f855dd0fb88"
    Storage_Queue_Data_Message_Processor="8a0f0c08-91a1-4084-bc3d-661d67233fed"
    Storage_Queue_Data_Message_Sender="c6a89b2d-59bc-44d0-9896-0f6e12d7b80a"
    Storage_Queue_Data_Reader="19e7f393-937e-4f77-808e-94535e297925"
    Support_Request_Contributor="cfd33db0-3dd1-45e3-aa9d-cdbdf3b6f24e"
    Traffic_Manager_Contributor="a4b10055-b0c7-44c2-b00f-c7b5b3550cf7"
    User_Access_Administrator="18d7d88d-d35e-4fb5-a5c3-7773c20a72d9"
    Virtual_Machine_Contributor="9980e02c-c2be-4d73-94e8-173b1dc7cf3c"
    Web_Plan_Contributor="2cc479cb-7b4d-49a8-b449-8c00fd0f0a4b"
    Website_Contributor="de139f84-1756-47ae-9be6-808fbbe84772"
    Azure_Service_Bus_Data_Owner="090c5cfd-751d-490a-894a-3ce6f1109419"
    Azure_Event_Hubs_Data_Owner="f526a384-b230-433a-b45c-95f59c4a2dec"
    Attestation_Contributor="bbf86eb8-f7b4-4cce-96e4-18cddf81d86e"
    HDInsight_Cluster_Operator="61ed4efc-fab3-44fd-b111-e24485cc132a"
    Cosmos_DB_Operator="230815da-be43-4aae-9cb4-875f7bd000aa"
    Hybrid_Server_Resource_Administrator="48b40c6e-82e0-4eb3-90d5-19e40f49b624"
    Hybrid_Server_Onboarding="5d1e5ee4-7c68-4a71-ac8b-0739630a3dfb"
    Azure_Event_Hubs_Data_Receiver="a638d3c7-ab3a-418d-83e6-5f17a39d4fde"
    Azure_Event_Hubs_Data_Sender="2b629674-e913-4c01-ae53-ef4638d8f975"
    Azure_Service_Bus_Data_Receiver="4f6d3b9b-027b-4f4c-9142-0e5a2a2247e0"
    Azure_Service_Bus_Data_Sender="69a216fc-b8fb-44d8-bc22-1f3c2cd27a39"
    Storage_File_Data_SMB_Share_Reader="aba4ae5f-2193-4029-9191-0cb91df5e314"
    Storage_File_Data_SMB_Share_Contributor="0c867c2a-1d8c-454a-a3db-ab2ea1bdc8bb"
    Private_DNS_Zone_Contributor="b12aa53e-6015-4669-85d0-8515ebb3ae7f"
    Storage_Blob_Delegator="db58b8e5-c6ad-4a2a-8342-4190687cbf4a"
    Desktop_Virtualization_User="1d18fff3-a72a-46b5-b4a9-0b38a3cd7e63"
    Storage_File_Data_SMB_Share_Elevated_Contributor="a7264617-510b-434b-a828-9731dc254ea7"
    Blueprint_Contributor="41077137-e803-4205-871c-5a86e6a753b4"
    Blueprint_Operator="437d2ced-4a38-4302-8479-ed2bcb43d090"
    Microsoft_Sentinel_Contributor="ab8e14d6-4a74-4a29-9ba8-549422addade"
    Microsoft_Sentinel_Responder="3e150937-b8fe-4cfb-8069-0eaf05ecd056"
    Microsoft_Sentinel_Reader="8d289c81-5878-46d4-8554-54e1e3d8b5cb"
    Policy_Insights_Data_Writer="66bb4e9e-b016-4a94-8249-4c0511c2be84"
    SignalR_AccessKey_Reader="04165923-9d83-45d5-8227-78b77b0a687e"
    Web_PubSub_Contributor="8cf5e20a-e4b2-4e9d-b3a1-5ceb692c2761"
    Azure_Connected_Machine_Onboarding="b64e21ea-ac4e-4cdf-9dc9-5b892992bee7"
    Managed_Services_Registration_assignment_Delete_Role="91c1777a-f3dc-4fae-b103-61d183457e46"
    App_Configuration_Data_Owner="5ae67dd6-50cb-40e7-96ff-dc2bfa4b606b"
    App_Configuration_Data_Reader="516239f1-63e1-4d78-a4de-a74fb236a071"
    Kubernetes_Cluster_Azure_Arc_Onboarding="34e09817-6cbe-4d01-b1a2-e0eac5743d41"
    Experimentation_Contributor="7f646f1b-fa08-80eb-a22b-edd6ce5c915c"
    Cognitive_Services_QnA_Maker_Reader="466ccd10-b268-4a11-b098-b4849f024126"
    Cognitive_Services_QnA_Maker_Editor="f4cc2bf9-21be-47a1-bdf1-5c5804381025"
    Experimentation_Administrator="7f646f1b-fa08-80eb-a33b-edd6ce5c915c"
    Remote_Rendering_Administrator="3df8b902-2a6f-47c7-8cc5-360e9b272a7e"
    Remote_Rendering_Client="d39065c4-c120-43c9-ab0a-63eed9795f0a"
    Managed_Application_Contributor_Role="641177b8-a67a-45b9-a033-47bc880bb21e"
    Security_Assessment_Contributor="612c2aa1-cb24-443b-ac28-3ab7272de6f5"
    Tag_Contributor="4a9ae827-6dc8-4573-8ac7-8239d42aa03f"
    Integration_Service_Environment_Developer="c7aa55d3-1abb-444a-a5ca-5e51e485d6ec"
    Integration_Service_Environment_Contributor="a41e2c5b-bd99-4a07-88f4-9bf657a760b8"
    Azure_Kubernetes_Service_Contributor_Role="ed7f3fbd-7b88-4dd4-9017-9adb7ce333f8"
    Azure_Digital_Twins_Data_Reader="d57506d4-4c8d-48b1-8587-93c323f6a5a3"
    Azure_Digital_Twins_Data_Owner="bcd981a7-7f74-457b-83e1-cceb9e632ffe"
    Hierarchy_Settings_Administrator="350f8d15-c687-4448-8ae1-157740a3936d"
    FHIR_Data_Contributor="5a1fc7df-4bf1-4951-a576-89034ee01acd"
    FHIR_Data_Exporter="3db33094-8700-4567-8da5-1501d4e7e843"
    FHIR_Data_Reader="4c8d0bbc-75d3-4935-991f-5f3c56d81508"
    FHIR_Data_Writer="3f88fce4-5892-4214-ae73-ba5294559913"
    Experimentation_Reader="49632ef5-d9ac-41f4-b8e7-bbe587fa74a1"
    Object_Understanding_Account_Owner="4dd61c23-6743-42fe-a388-d8bdd41cb745"
    Azure_Maps_Data_Contributor="8f5e0ce6-4f7b-4dcf-bddf-e6f48634a204"
    Cognitive_Services_Custom_Vision_Contributor="c1ff6cc2-c111-46fe-8896-e0ef812ad9f3"
    Cognitive_Services_Custom_Vision_Deployment="5c4089e1-6d96-4d2f-b296-c1bc7137275f"
    Cognitive_Services_Custom_Vision_Labeler="88424f51-ebe7-446f-bc41-7fa16989e96c"
    Cognitive_Services_Custom_Vision_Reader="93586559-c37d-4a6b-ba08-b9f0940c2d73"
    Cognitive_Services_Custom_Vision_Trainer="0a5ae4ab-0d65-4eeb-be61-29fc9b54394b"
    Key_Vault_Administrator="00482a5a-887f-4fb3-b363-3b7fe8e74483"
    Key_Vault_Crypto_User="12338af0-0e69-4776-bea7-57ae8d297424"
    Key_Vault_Secrets_Officer="b86a8fe4-44ce-4948-aee5-eccb2c155cd7"
    Key_Vault_Secrets_User="4633458b-17de-408a-b874-0445c86b69e6"
    Key_Vault_Certificates_Officer="a4417e6f-fecd-4de8-b567-7b0420556985"
    Key_Vault_Reader="21090545-7ca7-4776-b22c-e363652d74d2"
    Key_Vault_Crypto_Service_Encryption_User="e147488a-f6f5-4113-8e2d-b22465e65bf6"
    Azure_Arc_Kubernetes_Viewer="63f0a09d-1495-4db4-a681-037d84835eb4"
    Azure_Arc_Kubernetes_Writer="5b999177-9696-4545-85c7-50de3797e5a1"
    Azure_Arc_Kubernetes_Cluster_Admin="8393591c-06b9-48a2-a542-1bd6b377f6a2"
    Azure_Arc_Kubernetes_Admin="dffb1e0c-446f-4dde-a09f-99eb5cc68b96"
    Azure_Kubernetes_Service_RBAC_Cluster_Admin="b1ff04bb-8a4e-4dc4-8eb5-8693973ce19b"
    Azure_Kubernetes_Service_RBAC_Admin="3498e952-d568-435e-9b2c-8d77e338d7f7"
    Azure_Kubernetes_Service_RBAC_Reader="7f6c6a51-bcf8-42ba-9220-52d62157d7db"
    Azure_Kubernetes_Service_RBAC_Writer="a7ffa36f-339b-4b5c-8bdf-e2c188b2c0eb"
    Services_Hub_Operator="82200a5b-e217-47a5-b665-6d8765ee745b"
    Object_Understanding_Account_Reader="d18777c0-1514-4662-8490-608db7d334b6"
    SignalR_REST_API_Owner="fd53cd77-2268-407a-8f46-7e7863d0f521"
    Collaborative_Data_Contributor="daa9e50b-21df-454c-94a6-a8050adab352"
    Device_Update_Reader="e9dba6fb-3d52-4cf0-bce3-f06ce71b9e0f"
    Device_Update_Administrator="02ca0879-e8e4-47a5-a61e-5c618b76e64a"
    Device_Update_Content_Administrator="0378884a-3af5-44ab-8323-f5b22f9f3c98"
    Device_Update_Content_Reader="d1ee9a80-8b14-47f0-bdc2-f4a351625a7b"
    Cognitive_Services_Metrics_Advisor_Administrator="cb43c632-a144-4ec5-977c-e80c4affc34a"
    Cognitive_Services_Metrics_Advisor_User="3b20f47b-3825-43cb-8114-4bd2201156a8"
    Schema_Registry_Reader="2c56ea50-c6b3-40a6-83c0-9d98858bc7d2"
    Schema_Registry_Contributor="5dffeca3-4936-4216-b2bc-10343a5abb25"
    AgFood_Platform_Service_Reader="7ec7ccdc-f61e-41fe-9aaf-980df0a44eba"
    AgFood_Platform_Service_Contributor="8508508a-4469-4e45-963b-2518ee0bb728"
    AgFood_Platform_Service_Admin="f8da80de-1ff9-4747-ad80-a19b7f6079e3"
    Managed_HSM_contributor="18500a29-7fe2-46b2-a342-b16a415e101d"
    Security_Detonation_Chamber_Submitter="0b555d9b-b4a7-4f43-b330-627f0e5be8f0"
    SignalR_REST_API_Reader="ddde6b66-c0df-4114-a159-3618637b3035"
    SignalR_Service_Owner="7e4f1700-ea5a-4f59-8f37-079cfe29dce3"
    Reservation_Purchaser="f7b75c60-3036-4b75-91c3-6b41c27c1689"
    AzureML_Metrics_Writer="635dd51f-9968-44d3-b7fb-6d9a6bd613ae"
    Storage_Account_Backup_Contributor="e5e2a7ff-d759-4cd2-bb51-3152d37e2eb1"
    Experimentation_Metric_Contributor="6188b7c9-7d01-4f99-a59f-c88b630326c0"
    Project_Babylon_Data_Curator="9ef4ef9c-a049-46b0-82ab-dd8ac094c889"
    Project_Babylon_Data_Reader="c8d896ba-346d-4f50-bc1d-7d1c84130446"
    Project_Babylon_Data_Source_Administrator="05b7651b-dc44-475e-b74d-df3db49fae0f"
    Application_Group_Contributor="ca6382a4-1721-4bcf-a114-ff0c70227b6b"
    Desktop_Virtualization_Reader="49a72310-ab8d-41df-bbb0-79b649203868"
    Desktop_Virtualization_Contributor="082f0a83-3be5-4ba1-904c-961cca79b387"
    Desktop_Virtualization_Workspace_Contributor="21efdde3-836f-432b-bf3d-3e8e734d4b2b"
    Desktop_Virtualization_User_Session_Operator="ea4bfff8-7fb4-485a-aadd-d4129a0ffaa6"
    Desktop_Virtualization_Session_Host_Operator="2ad6aaab-ead9-4eaa-8ac5-da422f562408"
    Desktop_Virtualization_Host_Pool_Reader="ceadfde2-b300-400a-ab7b-6143895aa822"
    Desktop_Virtualization_Host_Pool_Contributor="e307426c-f9b6-4e81-87de-d99efb3c32bc"
    Desktop_Virtualization_Application_Group_Reader="aebf23d0-b568-4e86-b8f9-fe83a2c6ab55"
    Desktop_Virtualization_Application_Group_Contributor="86240b0e-9422-4c43-887b-b61143f32ba8"
    Desktop_Virtualization_Workspace_Reader="0fa44ee9-7a7d-466b-9bb2-2bf446b1204d"
    Disk_Backup_Reader="3e5e47e6-65f7-47ef-90b5-e5dd4d455f24"
    Disk_Restore_Operator="b50d9833-a0cb-478e-945f-707fcc997c13"
    Disk_Snapshot_Contributor="7efff54f-a5b4-42b5-a1c5-5411624893ce"
    Kubernetes_connected_cluster_role="5548b2cf-c94c-4228-90ba-30851930a12f"
    Security_Detonation_Chamber_Submission_Manager="a37b566d-3efa-4beb-a2f2-698963fa42ce"
    Security_Detonation_Chamber_Publisher="352470b3-6a9c-4686-b503-35deb827e500"
    Collaborative_Runtime_Operator="7a6f0e70-c033-4fb1-828c-08514e5f4102"
    CosmosRestoreOperator="5432c526-bc82-444a-b7ba-57c5b0b5b34f"
    FHIR_Data_Converter="a1705bd2-3a8f-45a5-8683-466fcfd5cc24"
    Quota_Request_Operator="0e5f05e5-9ab9-446b-b98d-1e2157c94125"
    EventGrid_Contributor="1e241071-0855-49ea-94dc-649edcd759de"
    Security_Detonation_Chamber_Reader="28241645-39f8-410b-ad48-87863e2951d5"
    Object_Anchors_Account_Reader="4a167cdf-cb95-4554-9203-2347fe489bd9"
    Object_Anchors_Account_Owner="ca0835dd-bacc-42dd-8ed2-ed5e7230d15b"
    WorkloadBuilder_Migration_Agent_Role="d17ce0a2-0697-43bc-aac5-9113337ab61c"
    Azure_Spring_Cloud_Data_Reader="b5537268-8956-4941-a8f0-646150406f0c"
    Cognitive_Services_Speech_Contributor="0e75ca1e-0464-4b4d-8b93-68208a576181"
    Cognitive_Services_Face_Recognizer="9894cab4-e18a-44aa-828b-cb588cd6f2d7"
    Media_Services_Account_Administrator="054126f8-9a2b-4f1c-a9ad-eca461f08466"
    Media_Services_Live_Events_Administrator="532bc159-b25e-42c0-969e-a1d439f60d77"
    Media_Services_Media_Operator="e4395492-1534-4db2-bedf-88c14621589c"
    Media_Services_Policy_Administrator="c4bba371-dacd-4a26-b320-7250bca963ae"
    Media_Services_Streaming_Endpoints_Administrator="99dba123-b5fe-44d5-874c-ced7199a5804"
    Stream_Analytics_Query_Tester="1ec5b3c1-b17e-4e25-8312-2acb3c3c5abf"
    AnyBuild_Builder="a2138dac-4907-4679-a376-736901ed8ad8"
    IoT_Hub_Data_Reader="b447c946-2db7-41ec-983d-d8bf3b1c77e3"
    IoT_Hub_Twin_Contributor="494bdba2-168f-4f31-a0a1-191d2f7c028c"
    IoT_Hub_Registry_Contributor="4ea46cd5-c1b2-4a8e-910b-273211f9ce47"
    IoT_Hub_Data_Contributor="4fc6c259-987e-4a07-842e-c321cc9d413f"
    Test_Base_Reader="15e0f5a1-3450-4248-8e25-e2afe88a9e85"
    Search_Index_Data_Reader="1407120a-92aa-4202-b7e9-c0e197c71c8f"
    Search_Index_Data_Contributor="8ebe5a00-799e-43f5-93ac-243d3dce84a7"
    Storage_Table_Data_Reader="76199698-9eea-4c19-bc75-cec21354c6b6"
    Storage_Table_Data_Contributor="0a9a7e1f-b9d0-4cc4-a60d-0319b160aaa3"
    DICOM_Data_Reader="e89c7a3c-2f64-4fa1-a847-3e4c9ba4283a"
    DICOM_Data_Owner="58a3b984-7adf-4c20-983a-32417c86fbc8"
    EventGrid_Data_Sender="d5a91429-5739-47e2-a06b-3470a27159e7"
    Disk_Pool_Operator="60fc6e62-5479-42d4-8bf4-67625fcc2840"
    AzureML_Data_Scientist="f6c7c914-8db3-469d-8ca1-694a8f32e121"
    Grafana_Admin="22926164-76b3-42b3-bc55-97df8dab3e41"
    Azure_Connected_SQL_Server_Onboarding="e8113dce-c529-4d33-91fa-e9b972617508"
    Azure_Relay_Sender="26baccc8-eea7-41f1-98f4-1762cc7f685d"
    Azure_Relay_Owner="2787bf04-f1f5-4bfe-8383-c8a24483ee38"
    Azure_Relay_Listener="26e0b698-aa6d-4085-9386-aadae190014d"
    Grafana_Viewer="60921a7e-fef1-4a43-9b16-a26c52ad4769"
    Grafana_Editor="a79a5197-3a5c-4973-a920-486035ffd60f"
    Automation_Contributor="f353d9bd-d4a6-484e-a77a-8050b599b867"
    Kubernetes_Extension_Contributor="85cb6faf-e071-4c9b-8136-154b5a04f717"
    Device_Provisioning_Service_Data_Reader="10745317-c249-44a1-a5ce-3a4353c0bbd8"
    Device_Provisioning_Service_Data_Contributor="dfce44e4-17b7-4bd1-a6d1-04996ec95633"
    Code_Signing_Certificate_Profile_Signer="2837e146-70d7-4cfd-ad55-7efa6464f958"
    Azure_Spring_Cloud_Service_Registry_Reader="cff1b556-2399-4e7e-856d-a8f754be7b65"
    Azure_Spring_Cloud_Service_Registry_Contributor="f5880b48-c26d-48be-b172-7927bfa1c8f1"
    Azure_Spring_Cloud_Config_Server_Reader="d04c6db6-4947-4782-9e91-30a88feb7be7"
    Azure_Spring_Cloud_Config_Server_Contributor="a06f5c24-21a7-4e1a-aa2b-f19eb6684f5b"
    Azure_VM_Managed_identities_restore_Contributor="6ae96244-5829-4925-a7d3-5975537d91dd"
    Azure_Maps_Search_and_Render_Data_Reader="6be48352-4f82-47c9-ad5e-0acacefdb005"
    Azure_Maps_Contributor="dba33070-676a-4fb0-87fa-064dc56ff7fb"
    Azure_Arc_VMware_VM_Contributor="b748a06d-6150-4f8a-aaa9-ce3940cd96cb"
    Azure_Arc_VMware_Private_Cloud_User="ce551c02-7c42-47e0-9deb-e3b6fc3a9a83"
    Azure_Arc_VMware_Administrator_role_="ddc140ed-e463-4246-9145-7c664192013f"
    Cognitive_Services_LUIS_Owner="f72c8140-2111-481c-87ff-72b910f6e3f8"
    Cognitive_Services_Language_Reader="7628b7b8-a8b2-4cdc-b46f-e9b35248918e"
    Cognitive_Services_Language_Writer="f2310ca1-dc64-4889-bb49-c8e0fa3d47a8"
    Cognitive_Services_Language_Owner="f07febfe-79bc-46b1-8b37-790e26e6e498"
    Cognitive_Services_LUIS_Reader="18e81cdc-4e98-4e29-a639-e7d10c5a6226"
    Cognitive_Services_LUIS_Writer="6322a993-d5c9-4bed-b113-e49bbea25b27"
    PlayFab_Reader="a9a19cc5-31f4-447c-901f-56c0bb18fcaf"
    Load_Test_Contributor="749a398d-560b-491b-bb21-08924219302e"
    Load_Test_Owner="45bb0b16-2f0c-4e78-afaa-a07599b003f6"
    PlayFab_Contributor="0c8b84dc-067c-4039-9615-fa1a4b77c726"
    Load_Test_Reader="3ae3fb29-0000-4ccd-bf80-542e7b26e081"
    Cognitive_Services_Immersive_Reader_User="b2de6794-95db-4659-8781-7e080d3f2b9d"
    Lab_Services_Contributor="f69b8690-cc87-41d6-b77a-a4bc3c0a966f"
    Lab_Services_Reader="2a5c394f-5eb7-4d4f-9c8e-e8eae39faebc"
    Lab_Assistant="ce40b423-cede-4313-a93f-9b28290b72e1"
    Lab_Operator="a36e6959-b6be-4b12-8e9f-ef4b474d304d"
    Lab_Contributor="5daaa2af-1fe8-407c-9122-bba179798270"
    Security_Admin="fb1c8493-542b-48eb-b624-b4c8fea62acd"
    Web_PubSub_Service_Owner="12cf5a90-567b-43ae-8102-96cf46c7d9b4"
    Web_PubSub_Service_Reader="bfb1c7d2-fb1a-466b-b2ba-aee63b92deaf"
    SignalR_App_Server="420fcaa2-552c-430f-98ca-3264be4806c7"
    Virtual_Machine_User_Login="fb879df8-f326-4884-b1cf-06f3ad86be52"
    Virtual_Machine_Administrator_Login="1c0163c0-47e6-4577-8991-ea5c82e286e4"
    Azure_Connected_Machine_Resource_Administrator="cd570a14-e51a-42ad-bac8-bafd67325302"
    Backup_Operator="00c29273-979b-4161-815c-10b084fb9324"
    Workbook_Contributor="e8ddcd69-c73f-4f9f-9844-4100522f16ad"
    Workbook_Reader="b279062a-9be3-42a0-92ae-8b3cf002ec4d"
    Monitoring_Contributor="749f88d5-cbae-40b8-bcfc-e573ddc772fa"
    Monitoring_Metrics_Publisher="3913510d-42f4-4e42-8a64-420c390055eb"
    Purview_role_1="8a3c2885-9b38-4fd2-9d99-91af537c1347"
    Purview_role_2="200bba9e-f0c8-430f-892b-6f0794863803"
    Purview_role_3="ff100721-1b9d-43d8-af52-42b69c1272db"
    Autonomous_Development_Platform_Data_Contributor="b8b15564-4fa6-4a59-ab12-03e1d9594795"
    Autonomous_Development_Platform_Data_Owner="27f8b550-c507-4db9-86f2-f4b8e816d59d"
    Autonomous_Development_Platform_Data_Reader="d63b75f7-47ea-4f27-92ac-e0d173aaf093"
    Key_Vault_Crypto_Officer="14b46e9e-c2b7-41b4-b07b-48a6ebf60603"
    Device_Update_Deployments_Reader="49e2f5d2-7741-4835-8efa-19e1fe35e47f"
    Device_Update_Deployments_Administrator="e4237640-0e3d-4a46-8fda-70bc94856432"
    Azure_Arc_VMware_Private_Clouds_Onboarding="67d33e57-3129-45e6-bb0b-7cc522f762fa"
    Chamber_Admin="4e9b8407-af2e-495b-ae54-bb60a55b1b5a"
    Microsoft_Sentinel_Automation_Contributor="f4c81013-99ee-4d62-a7ee-b3f1f648599a"
    CDN_Endpoint_Reader="871e35f6-b5c1-49cc-a043-bde969a0f2cd"
    Chamber_User="4447db05-44ed-4da3-ae60-6cbece780e32"
    Cognitive_Services_Speech_User="f2dc8367-1007-4938-bd23-fe263f013447"
    Windows_Admin_Center_Administrator_Login="a6333a3e-0164-44c3-b281-7a577aff287f"
    Azure_Kubernetes_Service_Policy_Add_On_Deployment="18ed5180-3e48-46fd-8541-4ea054d57064"
    Guest_Configuration_Resource_Contributor="088ab73d-1256-47ae-bea9-9de8e7131f31"
    Domain_Services_Reader="361898ef-9ed1-48c2-849c-a832951106bb"
    Domain_Services_Contributor="eeaeda52-9324-47f6-8069-5d5bade478b2"
    DNS_Resolver_Contributor="0f2ebee7-ffd4-4fc0-b3b7-664099fdad5d"
    Azure_Arc_Enabled_Kubernetes_Cluster_User_Role="00493d72-78f6-4148-b6c5-d3ce8e4799dd"
    Data_Operator_for_Managed_Disks="959f8984-c045-4866-89c7-12bf9737be2e"
    AgFood_Platform_Sensor_Partner_Contributor="6b77f0a0-0d89-41cc-acd1-579c22c17a67"
    Compute_Gallery_Sharing_Admin="1ef6a3be-d0ac-425d-8c01-acb62866290b"
    Scheduled_Patching_Contributor="cd08ab90-6b14-449c-ad9a-8f8e549482c6"
    DevCenter_Dev_Box_User="45d50f46-0b78-4001-a660-4198cbe8cd05"
    DevCenter_Project_Admin="331c37c6-af14-46d9-b9f4-e1909e1b95a0"
    Virtual_Machine_Local_User_Login="602da2ba-a5c2-41da-b01d-5360126ab525"
    Azure_Arc_ScVmm_VM_Contributor="e582369a-e17b-42a5-b10c-874c387c530b"
    Azure_Arc_ScVmm_Administrator_role="a92dfd61-77f9-4aec-a531-19858b406c87"
    Azure_Arc_ScVmm_Private_Clouds_Onboarding="6aac74c4-6311-40d2-bbdd-7d01e7c6e3a9"
    Azure_Arc_ScVmm_Private_Cloud_User="c0781e91-8102-4553-8951-97c6d4243cda"
    HDInsight_on_AKS_Cluster_Pool_Admin="7656b436-37d4-490a-a4ab-d39f838f0042"
    HDInsight_on_AKS_Cluster_Admin="fd036e6b-1266-47a0-b0bb-a05d04831731"
    FHIR_Data_Importer="4465e953-8ced-4406-a58e-0f6e3f3b530b"
    API_Management_Developer_Portal_Content_Editor="c031e6a8-4391-4de0-8d69-4706a7ed3729"
    VM_Scanner_Operator="d24ecba3-c1f4-40fa-a7bb-4588a071e8fd"
    Elastic_SAN_Owner="80dcbedb-47ef-405d-95bd-188a1b4ac406"
    Elastic_SAN_Reader="af6a70f8-3c9f-4105-acf1-d719e9fca4ca"
    Desktop_Virtualization_Virtual_Machine_Contributor="a959dbd1-f747-45e3-8ba6-dd80f235f97c"
    Desktop_Virtualization_Power_On_Off_Contributor="40c5ff49-9181-41f8-ae61-143b0e78555e"
    Desktop_Virtualization_Power_On_Contributor="489581de-a3bd-480d-9518-53dea7416b33"
    Elastic_SAN_Volume_Group_Owner="a8281131-f312-4f34-8d98-ae12be9f0d23"
    Access_Review_Operator_Service_Role="76cc9ee4-d5d3-4a45-a930-26add3d73475"
    Code_Signing_Identity_Verifier="4339b7cf-9826-4e41-b4ed-c7f4505dac08"
    Video_Indexer_Restricted_Viewer="a2c4a527-7dc0-4ee3-897b-403ade70fafb"
    Monitoring_Data_Reader="b0d8363b-8ddd-447d-831f-62ca05bff136"
    Azure_Kubernetes_Fleet_Manager_RBAC_Writer="5af6afb3-c06c-4fa4-8848-71a8aee05683"
    Azure_Kubernetes_Fleet_Manager_RBAC_Admin="434fb43a-c01c-447e-9f67-c3ad923cfaba"
    Azure_Kubernetes_Fleet_Manager_Contributor_Role="63bb64ad-9799-4770-b5c3-24ed299a07bf"
    Azure_Kubernetes_Fleet_Manager_RBAC_Reader="30b27cfc-9c84-438e-b0ce-70e35255df80"
    Azure_Kubernetes_Fleet_Manager_RBAC_Cluster_Admin="18ab4d3d-a1bf-4477-8ad9-8359bc988f69"
    Kubernetes_Namespace_User="ba79058c-0414-4a34-9e42-c3399d80cd5a"
    Data_Labeling_Labeler="c6decf44-fd0a-444c-a844-d653c394e7ab"
    Role_Based_Access_Control_Administrator="f58310d9-a9f6-439a-9e8d-f62e7b41a168"
    Template_Spec_Contributor="1c9b6475-caf0-4164-b5a1-2142a7116f4b"
    Template_Spec_Reader="392ae280-861d-42bd-9ea5-08ee6d83b80e"
    Microsoft_Sentinel_Playbook_Operator="51d6186e-6489-4900-b93f-92e23144cca5"
    Deployment_Environments_User="18e40d4e-8d2e-438d-97e1-9528336e149c"
    Azure_Spring_Apps_Connect_Role="80558df3-64f9-4c0f-b32d-e5094b036b0b"
    Azure_Spring_Apps_Remote_Debugging_Role="a99b0159-1064-4c22-a57b-c9b3caa1c054"
    AzureML_Registry_User="1823dd4f-9b8c-4ab6-ab4e-7397a3684615"
    AzureML_Compute_Operator="e503ece1-11d0-4e8e-8e2c-7a6c3bf38815"
    Azure_Center_for_SAP_solutions_service_role="aabbc5dd-1af0-458b-a942-81af88f9c138"
    Azure_Center_for_SAP_solutions_reader="05352d14-a920-4328-a0de-4cbe7430e26b"
    Azure_Center_for_SAP_solutions_administrator="7b0c7e81-271f-4c71-90bf-e30bdfdbc2f7"
    AppGw_for_Containers_Configuration_Manager="fbc52c3f-28ad-4303-a892-8a056630b8f1"
    FHIR_SMART_User="4ba50f17-9666-485c-a643-ff00808643f0"
    Cognitive_Services_OpenAI_Contributor="a001fd3d-188f-4b5d-821b-7da978bf7442"
    Cognitive_Services_OpenAI_User="5e0bd9bd-7b93-4f28-af87-19fc36ad61bd"
    Impact_Reporter="36e80216-a7e8-4f42-a7e1-f12c98cbaf8a"
    Impact_Reader="68ff5d27-c7f5-4fa9-a21c-785d0df7bd9e"
    Azure_Kubernetes_Service_Cluster_Monitoring_User="1afdec4b-e479-420e-99e7-f82237c7c5e6"
    ContainerApp_Reader="ad2dd5fb-cd4b-4fd4-a9b6-4fed3630980b"
    Azure_Connected_Machine_Resource_Manager="f5819b54-e033-4d82-ac66-4fec3cbf3f4c"
    SqlDb_Migration_Role="189207d4-bb67-4208-a635-b06afe8b2c57"
    Bayer_Ag_Powered_Services_GDU_Solution="c4bc862a-3b64-4a35-a021-a380c159b042"
    Bayer_Ag_Powered_Services_Imagery_Solution="ef29765d-0d37-4119-a4f8-f9f9902c9588"
    Azure_Center_for_SAP_solutions_Service_role_for_management="0105a6b0-4bb9-43d2-982a-12806f9faddb"
    Azure_Center_for_SAP_solutions_Management_role="6d949e1d-41e2-46e3-8920-c6e4f31a8310"
    Kubernetes_Agentless_Operator="d5a2ae44-610b-4500-93be-660a0c5f5ca6"
    Azure_Usage_Billing_Data_Sender="f0310ce6-e953-4cf8-b892-fb1c87eaf7f6"
    SqlMI_Migration_Role="1d335eef-eee1-47fe-a9e0-53214eba8872"
    Bayer_Ag_Powered_Services_CWUM_Solution="a9b99099-ead7-47db-8fcf-072597a61dfa"
    SqlVM_Migration_Role="ae8036db-e102-405b-a1b9-bae082ea436d"
    Azure_Front_Door_Domain_Contributor="0ab34830-df19-4f8c-b84e-aa85b8afa6e8"
    Azure_Front_Door_Secret_Reader="0db238c4-885e-4c4f-a933-aa2cef684fca"
    Azure_Front_Door_Secret_Contributor="3f2eb865-5811-4578-b90a-6fc6fa0df8e5"
    Azure_Front_Door_Domain_Reader="0f99d363-226e-4dca-9920-b807cf8e1a5f"
    Azure_Stack_HCI_Administrator="bda0d508-adf1-4af0-9c28-88919fc3ae06"
    MySQL_Backup_And_Export_Operator="d18ad5f3-1baf-4119-b49b-d944edb1f9d0"
    LocalNGFirewallAdministrator_role="a8835c7d-b5cb-47fa-b6f0-65ea10ce07a2"
    LocalRulestacksAdministrator_role="bfc3b73d-c6ff-45eb-9a5f-40298295bf20"
    Azure_Extension_for_SQL_Server_Deployment="7392c568-9289-4bde-aaaa-b7131215889d"
    Azure_Maps_Data_Read_and_Batch_Role="d6470a16-71bd-43ab-86b3-6f3a73f4e787"
    API_Management_Service_Workspace_API_Product_Manager="d59a3e9c-6d52-4a5a-aeed-6bf3cf0e31da"
    API_Management_Workspace_API_Developer="56328988-075d-4c6a-8766-d93edd6725b6"
    API_Management_Workspace_Reader="ef1c2c96-4a77-49e8-b9a4-6179fe1d2fd2"
    API_Management_Workspace_API_Product_Manager="73c2c328-d004-4c5e-938c-35c6f5679a1f"
    API_Management_Service_Workspace_API_Developer="9565a273-41b9-4368-97d2-aeb0c976a9b3"
    API_Management_Workspace_Contributor="0c34c906-8d99-4cb7-8bb7-33f5b0a1a799"
    Storage_File_Data_Privileged_Reader="b8eda974-7b85-4f76-af95-65846b26df6d"
    Storage_File_Data_Privileged_Contributor="69566ab7-960f-475b-8e7c-b3118f30c6bd"
    Windows_365_Network_User="7eabc9a4-85f7-4f71-b8ab-75daaccc1033"
    Windows365SubscriptionReader="3d55a8f6-4133-418d-8051-facdb1735758"
    Windows_365_Network_Interface_Contributor="1f135831-5bbe-4924-9016-264044c00788"
    App_Compliance_Automation_Reader="ffc6bbe0-e443-4c3b-bf54-26581bb2f78e"
    App_Compliance_Automation_Administrator="0f37683f-2463-46b6-9ce7-9b788b988ba2"
    Azure_Sphere_Contributor="8b9dfcab-4b77-4632-a6df-94bd07820648"
    SaaS_Hub_Contributor="e9b8712a-cbcf-4ea7-b0f7-e71b803401e6"
    Azure_Sphere_Reader="c8ae6279-5a0b-4cb2-b3f0-d4d62845742c"
    Azure_Sphere_Publisher="6d994134-994b-4a59-9974-f479f0b227fb"
    Azure_Machine_Learning_Workspace_Connection_Secrets_Reader="ea01e6af-a1c1-4350-9563-ad00f8c72ec5"
    Procurement_Contributor="be1a1ac2-09d3-4261-9e57-a73a6e227f53"
    Cognitive_Search_Serverless_Data_Contributor="7ac06ca7-21ca-47e3-a67b-cbd6e6223baf"
    Cognitive_Search_Serverless_Data_Reader="79b01272-bf9f-4f4c-9517-5506269cf524"
    Community_Owner_Role="5e28a61e-8040-49db-b175-bb5b88af6239"
    Firmware_Analysis_Admin="9c1607d1-791d-4c68-885d-c7b7aaff7c8a"
    Key_Vault_Data_Access_Administrator="8b54135c-b56d-4d72-a534-26097cfdc8d8"
    Defender_for_Storage_Data_Scanner="1e7ca9b1-60d1-4db8-a914-f2ca1ff27c40"
    Compute_Diagnostics_Role="df2711a6-406d-41cf-b366-b0250bff9ad1"
    Elastic_SAN_Network_Admin="fa6cecf6-5db3-4c43-8470-c540bcb4eafa"
    Cognitive_Services_Usages_Reader="bba48692-92b0-4667-a9ad-c31c7b334ac2"
    PostgreSQL_Flexible_Server_Long_Term_Retention_Backup_Role="c088a766-074b-43ba-90d4-1fb21feae531"
    Search_Parameter_Manager="a02f7c31-354d-4106-865a-deedf37fa038"
    Virtual_Machine_Data_Access_Administrator="66f75aeb-eabe-4b70-9f1e-c350c4c9ad04"
    Logic_Apps_Standard_Developer="523776ba-4eb2-4600-a3c8-f2dc93da4bdb"
    Logic_Apps_Standard_Contributor="ad710c24-b039-4e85-a019-deb4a06e8570"
    Logic_Apps_Standard_Operator="b70c96e9-66fe-4c09-b6e7-c98e69c98555"
    Logic_Apps_Standard_Reader="4accf36b-2c05-432f-91c8-5c532dff4c73"
    IPAM_Pool_Contributor="7b3e853f-ad5d-4fb5-a7b8-56a3581c7037"
    SpatialMapsAccounts_Account_Owner="e9c9ed2b-2a99-4071-b2ff-5b113ebf73a1"
    Azure_Resource_Notifications_System_Topics_Subscriber="0b962ed2-6d56-471c-bd5f-3477d83a7ba4"
    Elastic_SAN_Volume_Importer="90e8b822-3e73-47b5-868a-787dc80c008f"
    Elastic_SAN_Snapshot_Exporter="1c4770c0-34f7-4110-a1ea-a5855cc7a939"
    Community_Contributor_Role="49435da6-99fe-48a5-a235-fc668b9dc04a"
    EventGrid_TopicSpaces_Subscriber="4b0f2fd7-60b4-4eca-896f-4435034f8bf5"
    EventGrid_TopicSpaces_Publisher="a12b0b94-b317-4dcd-84a8-502ce99884c6"
    Data_Boundary_Tenant_Administrator="d1a38570-4b05-4d70-b8e4-1100bcf76d12"
    DeID_Realtime_Data_User="bb6577c4-ea0a-40b2-8962-ea18cb8ecd4e"
    DeID_Batch_Data_Reader="b73a14ee-91f5-41b7-bd81-920e12466be9"
    DeID_Batch_Data_Owner="8a90fa6b-6997-4a07-8a95-30633a7c97b9"
    Carbon_Optimization_Reader="fa0d39e6-28e5-40cf-8521-1eb320653a4c"
    Landing_Zone_Management_Owner="38863829-c2a4-4f8d-b1d2-2e325973ebc7"
    Landing_Zone_Management_Reader="8fe6e843-6d9e-417b-9073-106b048f50bb"
    Azure_Stack_HCI_Device_Management_Role="865ae368-6a45-4bd1-8fbf-0d5151f56fc1"
    Azure_Customer_Lockbox_Approver_for_Subscription="4dae6930-7baf-46f5-909e-0383bc931c46"
    Azure_Resource_Bridge_Deployment_Role="7b1f81f9-4196-4058-8aae-762e593270df"
    Azure_Stack_HCI_VM_Reader="4b3fe76c-f777-4d24-a2d7-b027b0f7b273"
    Azure_AI_Developer="64702f94-c441-49e6-a78b-ef80e0188fee"
    Azure_Stack_HCI_VM_Contributor="874d1c73-6003-4e60-a13a-cb31ea190a85"
    Deployment_Environments_Reader="eb960402-bf75-4cc3-8d68-35b34f960f72"
    EventGrid_Data_Receiver="78cbd9e7-9798-4e2e-9b5a-547d9ebb31fb"
    EventGrid_Data_Contributor="1d8c3fe3-8864-474b-8749-01e3783e8157"
    Advisor_Reviews_Contributor="8aac15f0-d885-4138-8afa-bfb5872f7d13"
    Advisor_Reviews_Reader="c64499e0-74c3-47ad-921c-13865957895c"
    Azure_AI_Inference_Deployment_Operator="3afb7f49-54cb-416e-8c09-6dc049efa503"
    Connected_Cluster_Managed_Identity_CheckAccess_Reader="65a14201-8f6c-4c28-bec4-12619c5a9aaa"
    AgFood_Platform_Dataset_Admin="a8d4b70f-0fb9-4f72-b267-b87b2f990aec"
    Azure_Front_Door_Profile_Reader="662802e2-50f6-46b0-aed2-e834bacc6d12"
    Enclave_Reader_Role="86fede04-b259-4277-8c3e-e26b9865abd8"
    Azure_Kubernetes_Service_Hybrid_Cluster_User_Role="fc3f91a1-40bf-4439-8c46-45edbd83563a"
    Azure_Kubernetes_Service_Hybrid_Cluster_Admin_Role="b5092dac-c796-4349-8681-1a322a31c3f9"
    Azure_Kubernetes_Service_Hybrid_Contributor_Role="e7037d40-443a-4434-a3fb-8cd202011e1d"
    Enclave_Owner_Role="3d5f3eff-eb94-473d-91e3-7aac74d6c0bb"
    Enclave_Contributor_Role="19feefae-eacc-4106-81fd-ac34c0671f14"
    Community_Reader_Role="e6aadb6b-e64f-41c0-9392-d2bba3bc3ebc"
    Storage_Account_Encryption_Scope_Contributor_Role="a316ed6d-1efe-48ac-ac08-f7995a9c26fb"
    Operator_Nexus_Key_Vault_Writer_Service_Role="44f0a1a8-6fea-4b35-980a-8ff50c487c97"
    Key_Vault_Crypto_Service_Release_User="08bbd89e-9f13-488c-ac41-acfcb10c90ab"
    KubernetesRuntime_Storage_Class_Contributor_Role="0cd9749a-3aaf-4ae5-8803-bd217705bf3b"
    Azure_Programmable_Connectivity_Gateway_User="609c0c20-e0a0-4a71-b99f-e7e755ac493d"
    Key_Vault_Certificate_User="db79e9a7-68ee-4b58-9aeb-b90e7c24fcba"
    Azure_Spring_Apps_Managed_Components_Log_Reader_Role="52fd16bd-6ed5-46af-9c40-29cbd7952a29"
    Azure_Spring_Apps_Application_Configuration_Service_Log_Reader_Role="6593e776-2a30-40f9-8a32-4fe28b77655d"
    Azure_Spring_Apps_Spring_Cloud_Gateway_Log_Reader_Role="4301dc2a-25a9-44b0-ae63-3636cf7f2bd2"
    Azure_Edge_On_Site_Deployment_Engineer="207bcc4b-86a6-4487-9141-d6c1f4c238aa"
    Azure_API_Center_Data_Reader="c7244dfb-f447-457d-b2ba-3999044d1706"
    Azure_impact_insight_reader="dfb2f09d-25f8-4558-8986-497084006d7a"
    Defender_Kubernetes_Agent_Operator="8bb6f106-b146-4ee6-a3f9-b9c5a96e0ae5"
    Azure_RedHat_OpenShift_Cloud_Controller_Manager_Role="a1f96423-95ce-4224-ab27-4e3dc72facd4"
    Azure_RedHat_OpenShift_Storage_Operator_Role="5b7237c5-45e1-49d6-bc18-a1f62f400748"
    Azure_RedHat_OpenShift_Network_Operator_Role="be7a6435-15ae-4171-8f30-4a343eff9e8f"
    Azure_RedHat_OpenShift_Image_Registry_Operator_Role="8b32b316-c2f5-4ddf-b05b-83dacd2d08b5"
    Azure_RedHat_OpenShift_Azure_Files_Storage_Operator_Role="0d7aedc0-15fd-4a67-a412-efad370c947e"
    Azure_RedHat_OpenShift_Service_Operator="4436bae4-7702-4c84-919b-c4069ff25ee2"
    Azure_RedHat_OpenShift_Machine_API_Operator_Role="0358943c-7e01-48ba-8889-02cc51d78637"
    Azure_RedHat_OpenShift_Cluster_Ingress_Operator_Role="0336e1d3-7a87-462b-b6db-342b63f7802c"
    Azure_Sphere_Owner="5a382001-fe36-41ff-bba4-8bf06bd54da9"
